<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00001000EnderecoPropostaService;

class Sm00001000EnderecoPropostaController extends SMCrud {
    
    protected $dataSourceName = "fct_enderecoorca_widget";
    protected $enderecoPropostaService;
    
    public function __construct($crudService, $environment, Sm00001000EnderecoPropostaService $enderecoPropostaService) {
        parent::__construct($crudService, $environment);
        $this->enderecoPropostaService = $enderecoPropostaService;
    }
    
    /**
     * Verifica se já existe um registro com o mesmo tipo de endereço que se está tentando salvar.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function validarTipoEndereco(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrenderecoorca = $row["NRENDERECOORCA"];
            $cdtipoendereco = $row["CDTIPOENDERECO"];
            
            $nrorg = $this->environment->getNrOrg();
            
            $existe = $this->enderecoPropostaService->verificarSeExisteTipoEndereco($nrseqorcamento, $nrenderecoorca, $cdtipoendereco, $nrorg);
            
            $response->addDataSet(new DataSet($this->dataSourceName, array("existe" => $existe)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>